# Repository Platform Overview

This document defines our strategy for hosting, organizing, and managing repositories for Gluebox.com LLC projects.

We intentionally split public-facing, ecosystem-integrated projects from internal, private platform code to balance discoverability, collaboration, and company control.

---

## ✅ GitLab (Public / Ecosystem-Facing Repos)

**Purpose:**  
Public, ecosystem-facing Drupal projects intended for maximum discoverability, contribution, and integration with Packagist and the Drupal.org ecosystem.

### Repositories

- **RSVP-System-Recipes**  
  - [https://gitlab.com/rsvp-system/rsvp-recipes](https://gitlab.com/rsvp-system/rsvp-recipes)  
  - Documentation, configuration, install guides for the RSVP System Drupal recipe
  - Includes calendar integration, scheduling content types, ECA automation rules
  - Clear, user-friendly recipe approach for site builders

- **RSVP-System-Module**  
  - [https://gitlab.com/rsvp-system/rsvp-system-module](https://gitlab.com/rsvp-system/rsvp-system-module)  
  - Custom Drupal module code
  - PHP, Composer.json
  - Packagist-ready
  - Clean, reusable code for developer integration

- **RSVP-System Documentation Site**  
  - [https://gitlab.com/rsvp-system/rsvp-system](https://gitlab.com/rsvp-system/rsvp-system)  
  - Builds and maintains [https://docs.rsvp-system.org](https://docs.rsvp-system.org)
  - Contains site generator code, theme, and publishing pipeline

---

## ✅ Self-hosted Gitea (code.gluebox.com) (Private / Controlled Repos)

**Purpose:**  
Private/internal platform code and branded tools that remain under company control. Allows unlimited private repos with fine-grained access management.

### Repositories

- **Gluebox-Node**
  - Installer scripts and system management tools for the Gluebox Node appliance
  - Deployment automation

- **RSVP-Theme**
  - Radix-based Drupal theme customized for events and RSVP branding
  - Branding assets

- **Platform-Tools**
  - Private CLI tools, packaging scripts, internal automation
  - Helper utilities for company operations

- **GlueBox-GPT**  
  - [https://code.gluebox.com/tux/GlueBox-GPT](https://code.gluebox.com/tux/GlueBox-GPT)  
  - Stores RAG (Red-Amber-Green) status files, planning documents, and AI assistant instructions for managing the Gluebox Node GPT
  - Central planning resource for Gluebox LLC projects

---

## ✅ Notes

- Public-facing repos support **Drupal community integration** and **Packagist distribution**, boosting discoverability and open source collaboration.
- Private repos maintain **company control** over platform deployment, theming, internal planning, and tooling.
- This split allows clear separation of concerns while keeping internal IP protected and brand-aligned.
